# -*- coding: utf-8 -*-
"""
Created on Fri Apr 26 09:50:43 2024

@author: Thomas
"""

#
# ----------------------------------------------------------------------------------------------------------------------
#
#     Title of script
#
# ----------------------------------------------------------------------------------------------------------------------


# ----------------------------------------------------------------------------------------------------------------------
#
#          Imports and global variables
#      \**********************************/
#
import numpy as np

import time

import xarray as xr

import os

import sys

import matplotlib.pyplot as plt

from scipy.interpolate import griddata

# ----------------------------------------------------------------------------------------------------------------------
#
#           Functions
#       \***************/
#
#
#   Here you can define usefull functions to be used in the main
#
"""##############################################################################################################"""
def ti():
    return time.time()
"""##############################################################################################################"""

def open_mar(path):
    
    return xr.open_mfdataset(path+"*.nc")
    
"""##############################################################################################################"""

def main_fire(path_to_fire, path_to_MAR):
    
    print("open data")
    MAR = open_mar(path_to_MAR)
    
    lon_mar = MAR.LON.isel(time=0).values
    lat_mar = MAR.LAT.isel(time=0).values
    
    lon_e, lat_e, data_e = read_data(path_to_fire)
    
    flash = interpol(lon_mar, lat_mar, lon_e, lat_e, data_e)
    
    write_file(lon_mar, lat_mar, flash)
        
"""##############################################################################################################"""

def read_data(path_to_fire):
    
    with open(path_to_fire, "r") as f:
       full = f.read()
       
       cleaned = full.replace("   "," ").replace("  "," ").replace("\n"," ").split(" ")
       cleaned = np.array(cleaned)
       
       cleaned_array = cleaned[cleaned != ''].astype(float)
       
       reshaped = cleaned_array.reshape(-1,12)*365/12
       
    lat = np.arange(-90,90,0.5)
    lon = np.arange(-180,180,0.5)
    
    # Use meshgrid to create the grid of coordinates
    lon_grid, lat_grid = np.meshgrid(lon, lat)

    
    monthly_values = reshaped

    # Reshape monthly values to (360, 720, 12)
    reshaped_data = monthly_values.reshape((360, 720, 12))
    
    reshaped_lon = lon_grid.reshape((360, 720))
    
    reshaped_lat = lat_grid.reshape((360, 720))
    
    return reshaped_lon, reshaped_lat, reshaped_data
    

"""##############################################################################################################"""        

def interpol(lon_m, lat_m, lon_e, lat_e, data_e):
    
    shape_to_get = np.shape(lon_m)
    
    flash = np.zeros((shape_to_get+ (12,)))
    
    for month in range(data_e.shape[2]):
        
        month_data = data_e[:, :, month]
        
        interpolated_att1 = griddata(
            (lon_e.flatten(), lat_e.flatten()),
            month_data.flatten(),
            (lon_m.flatten(), lat_m.flatten()),
            method='linear'
        )
        
        interpolated_att1 = interpolated_att1.reshape(shape_to_get)
        
        flash[:,:,month] = interpolated_att1
        
    return flash
        
def write_file(lon_m, lat_m, data):
    var_values = data
    
    print("Start writing the lightning file")
    for i in np.arange(0,np.shape(lon_m)[1]):
        for j in np.arange(0,np.shape(lat_m)[0]):
            
            
            lo = lon_m[j,i]
            la = lat_m[j,i]
            
            va = var_values[j,i,:]
            
            f = open("lightning.dat", "a")
            text =f"{lo:8.3f} {la:8.3f}" +"\t" + "\t".join(f"{x:8.3E}" for x in va) + "\n"
            f.write(text)
            f.close()
 
#           Main
#       \**********/
#
#
#   Here you can define the instructions that are called when you execute this file
#
if __name__ == '__main__':
    
    t0=ti()
    
    path_to_fire = "E:/Car_files/data.ascii"
    path_to_MAR = "E:/MAR_data_raw_BE/MERRA/"
    
    main_fire(path_to_fire,path_to_MAR)
  
    t1=ti()
    print('Programme compiled in ',t1-t0, 'sec')