# -*- coding: utf-8 -*-
"""
Created on Fri Apr 26 09:50:43 2024

@author: Thomas
"""

#
# ----------------------------------------------------------------------------------------------------------------------
#
#     Create management file for CARAIB
#
# ----------------------------------------------------------------------------------------------------------------------


# ----------------------------------------------------------------------------------------------------------------------
#
#          Imports and global variables
#      \**********************************/
#
import numpy as np

import time

import xarray as xr

import os

import sys

import matplotlib.pyplot as plt

from scipy.interpolate import griddata
import calendar

# ----------------------------------------------------------------------------------------------------------------------
#
#           Functions
#       \***************/
#
#
#   Here you can define usefull functions to be used in the main
#
"""##############################################################################################################"""
def ti():
    return time.time()
"""##############################################################################################################"""

def open_mar(path):
    
    return xr.open_mfdataset(path+"*.nc")
    
"""##############################################################################################################"""

def main_manag(path_to_manag, path_to_MAR, manag_type,ys,ye):
    
    print("open data")
    MAR = open_mar(path_to_MAR)
    
    lon_mar = MAR.LON.isel(time=0).values
    lat_mar = MAR.LAT.isel(time=0).values
    
    
    write_file(lon_mar, lat_mar, path_to_manag, manag_type,ys,ye)
        
"""##############################################################################################################"""

        
def write_file(lon_m, lat_m,  path_to_manag, manag_type,ys,ye):
    
    if not os.path.isdir(path_to_manag):
        os.mkdir(path_to_manag)
    
    for yy in np.arange(ys,ye+1,1):
        
        va = manag_type
        
        if calendar.isleap(yy):
            if manag_type[2]==365:
                va[2]=366
                
    
        print("Start writing the file")
        for i in np.arange(0,np.shape(lon_m)[1]):
            for j in np.arange(0,np.shape(lat_m)[0]):
                
                
                lo = lon_m[j,i]
                la = lat_m[j,i]
                
                f = open(path_to_manag+f"manag{yy}.dat", "a")
                text =f"{lo:8.3f} {la:8.3f}"
                for x in np.arange(0,10,1):
                    text = text + "\t"+ "\t".join(str(y) for y in va[0:3]) + "\t"+ "\t".join(str(round(float(y),2)) for y in va[3:])

                text = text + "\n"
                f.write(text)
                f.close()

#           Main
#       \**********/
#
#
#   Here you can define the instructions that are called when you execute this file
#
if __name__ == '__main__':
    
    t0=ti()
    
    path_to_manag = "./man/"
    path_to_MAR = "E:/MAR_data_raw_BE/MERRA/"
    manage_type = [2,1,365,0,0] #full cut
    # manage_type = [1,1,150,50,50] #user defined
    ys = 2009 #starting year -1
    ye = 2020 #end year
   
    main_manag(path_to_manag, path_to_MAR, manage_type,ys,ye)
  
    t1=ti()
    print('Programme compiled in ',t1-t0, 'sec')