c=======================================================================
c***********************************************************************
      subroutine fire(ngt)
c***********************************************************************
c=======================================================================
      implicit none
      
c=======================================================================
c     This routine calculates probability of fire and area burned 
c     INPUTS:
c     commons must be set and iday in common cte
c     OUTPUTS:
c     Pf = Probability of fire
c     frac_burn = fraction of the pixel burned
c     area_burn = area burned (m2)
c=======================================================================

      include './com_18/parameter.common' 
      include './com_18/annppf.common'
      include './com_18/abobio.common'
      include './com_18/bagnum.common'      
      include './com_18/burned.common'
      include './com_18/climin.common'
      include './com_18/coord.common'
      include './com_18/crops.common'      
      include './com_18/cstpi.common'
      include './com_18/cte.common'
      include './com_18/ecoin.common'
      include './com_18/fire_emi.common'
      include './com_18/firevpar.common'      
      include './com_18/griddata.common'      
c      include './com_18/inidata.common'
      include './com_18/landuse.common'
      include './com_18/litiere.common'
      include './com_18/nspc.common'
      include './com_18/npp.common'
      include './com_18/plant_evol.common'
      include './com_18/plant_pool.common'
      include './com_18/soil_marie.common'
      include './com_18/soil_pool.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer iday,iday2,ip,ipool,kpool

      real*4 area_mean,area_star,argth,beta_e,beta_m,
     &   beta_root,beta_xl,bio_low,bio_up,biom_ag,f_burned,
     &   fac_flash,facbio,g0wind,gwinds,h_broot,
     &   pbio,pign,pign_hum,pmst,q,uf_b,uf_p,ufmax,winkmh,
     &   xign,xlf_b,xlf_low,xlf_up
      
c-----------------------------------------------
      yfnoburn = 1.

      if(ifire.eq.1) then

       fday(nd) = 1.

       do iday = 1, nd

        iday2 = iday - 1
        if(iday.eq.1) iday2 = nd
	
c fraction of aboveground biomass for each pool and each pft (constant)
        do ip = 1, npft0
         do ipool = 1, npool
          if(ipool.eq.1)then 
           fag_pft(ip,ipool) = 1.00
          else
	   if (carbon(ip,2,iday2).ge.1.e-5) then 
            fag_pft(ip,ipool)= 
     &       1.- (root_biomass(ip,iday2)/carbon(ip,2,iday2))
           else
	    fag_pft(ip,ipool)=0.
	   endif
          endif 
         end do
        end do			

c Fire module from Arora and Boer, 2005. J. Geophys. Res., 110, G02008,
c                         doi  10:1029/2005JG000042 
   

c open writing file
c      open(10,file='./fire.res')


c  Que j'aime a faire connaitre un nombre utile aux sages
c  3  .1  4   1   5       9      2   6      5    3    5
c      pi = 3.14159265
c Lightning frequency (flashes/km2/month)
c       xl_flash(iday) = 0.41-0.41*cos(2.*pi*float(iday)/365.)
c Probability of extinguishing fire over one day

       q_extinc(iday) = 0.5

c Aboveground biomass for each plant biomf_ag (g C m-2)
c Aboveground biomass and litter carbon biom_ag (g C m-2)

       biom_ag = 0.
       do ip = 1, npft0
        biomf_ag(ip) = 0.
        do ipool = 1, npool
         biomf_ag(ip)=biomf_ag(ip) + 
     &          carbon(ip,ipool,iday2)*fag_pft(ip,ipool) 
        end do
        biom_ag = biom_ag + frac(ip)*biomf_ag(ip)
       end do
       
       do kpool = 1, 2
         biom_ag = biom_ag + xlit(kpool,iday2)
       end do

       Bio_low = 200.
       Bio_up = 1000.
       beta_e = 0.35
       xlf_low = 0.02
       xlf_up = 0.85
       pign_hum = 0.
       g0wind = 0.1
c maximum fire spread rate (km/day)
       ufmax = 86400.*0.13/1000.

c Fire Occurrence probability
c   Fire occurrence probability linked to biomass (Pbio)
       facbio = (biom_ag-Bio_low)/(Bio_up-Bio_low)
       Pbio = max(0.,min(1.,facbio))

c   Fire occurrence probability linked to soil moisture (Pmst)  
       beta_root = max(0.,min(1.,water(iday)))
       argth=1.75*beta_root/beta_e
       Pmst = 1. - tanh(argth*argth)

c   Fire occurrence probability linked to ignition source (Pign)
       fac_flash = (0.25*xl_flash(iday)-xlf_low)/(xlf_up-xlf_low)
       beta_xl = max(0.,min(1.,fac_flash))
       xIgn=beta_xl/(beta_xl+exp(1.5-6.*beta_xl))
       Pign = xIgn + (1.-xIgn)*pign_hum

c   Fire occurrence probability linked to all factors (Pf)
       Pf(iday) = Pbio*Pmst*Pign        

c Area burned  
c   dependence of fire spread on soil wetness (h_broot) (dimensionless)
       beta_m = 1.
       if (beta_root.le.beta_e) beta_m = beta_root/beta_e
       h_broot = (1-beta_m)*(1.-beta_m) 
c   dependence of fire spread on wind speed (gwinds)(dimensionless)
       winkmh = 3.6*win(iday)
       gwinds = 1.-(1.-g0wind)*exp(-winkmh*winkmh/2500.)
c   downwind fire propagation speed uf_p (km/day)
       uf_p = ufmax*gwinds*h_broot
c   backspread fire propagation speed uf_b (km/day)     
       uf_b = 0.2 * uf_p
c   length-to-breadth ratio of fire xLf_B (dimensionless)
       xLf_B = 1.+10.*(1.-exp(-0.017*winkmh))
c   Area burned in one day (area_star)
       area_star = pi*(uf_p+uf_b)*(uf_p+uf_b)/(4.*xLf_B)
c   Mean area (km2) burned per 1000 km2 (over the whole duration of fire) 
       q = q_extinc(iday)
       area_mean = area_star*(1.-q)*(2.-q)/(q*q)
       if (area_mean.lt.0.)area_mean=0.
       if (area_mean.gt.1000.)area_mean=1000.
c   Fraction burned
       f_burned = Pf(iday)*area_mean/1000.   
       

c   Non-burned fraction        
       fnoburn(iday) = 1. - f_burned
	
c   Yearly cumulated non-burned fraction                  
       yfnoburn = fnoburn(iday)*yfnoburn
	
c   Cumulated non-burned fraction at day iday 	
       fday(iday) = yfnoburn

c   Burned fraction
       frac_burn(iday) = fday(iday2)-fday(iday)
       if (frac_burn(iday).lt.0.) frac_burn(iday)=0.      
	
c   Area burned per pixel       (m2)
       area_burn(iday) = frac_burn(iday)*areapix(ngt)*frac_nat(ngt)
     		

        do ip = 1, npft0
          if (frac(ip).gt.1.e-7) then
	  
c=======================================================================
c     Fire carbon emission per PFT
c     emi_burn_veg = carbon emission for each pool per day and per m2 
c                    of PFT (g C m-2 day-1) 
c
c     The sum over ip of:
c       frac(ip)*(emi_burn_veg(ip,1,iday)+emi_burn_veg(ip,2,iday))
c     provides the total carbon emission by fires per day and per m2 
c=======================================================================

           emi_burn_veg(ip,1,iday) = 
     &       frac_burn(iday)*phi_L(ip)*carbon(ip,1,iday)
           emi_burn_veg(ip,2,iday) = frac_burn(iday)*phi_S(ip)
     &       *(carbon(ip,2,iday)-root_biomass(ip,iday))
     &       +frac_burn(iday)*phi_R(ip)*root_biomass(ip,iday)
     
c=======================================================================
c     Fire mortality per PFT
c     xlit_burn = litter production due to fire for each pool per day 
c                 and per m2 of PFT (g C m-2 day-1)
c
c     The sum over ip of:
c       frac(ip)*(xlit_burn(ip,1,iday)+xlit_burn(ip,2,iday))
c     provides the total litter production by fires per day and per m2
c======================================================================= 	
          
           xlit_burn(ip,1,iday) = 
     &       frac_burn(iday)*psi_L(ip)*carbon(ip,1,iday)
           xlit_burn(ip,2,iday) = frac_burn(iday)*psi_S(ip)
     &       *(carbon(ip,2,iday)-root_biomass(ip,iday))
     &       +frac_burn(iday)*psi_R(ip)*root_biomass(ip,iday)
     
           do ipool = 1, npool
               xlit_prod(ip,ipool,iday) = xlit_prod(ip,ipool,iday)
     &               + xlit_burn(ip,ipool,iday)                   
           enddo
            
          endif
       
         enddo
        
        enddo           
        
      endif

      return
      end subroutine fire