c=======================================================================
c***********************************************************************
      subroutine generator (graine,iprint)
c***********************************************************************
c=======================================================================

c=======================================================================
c!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
c!!!!!Routine de generation des annees de pluie et de temperatures.!!!!!
c!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
c  routine generant une annee de pluie pour chaque climat:
c  tire 365 nombres au hasard entre 0 et 1,compare avec la 
c  proba apropriee en fonction du resultat precedent puis 
c  calcule le nombre de jours de pluie pour chaque mois.
c  !!!!!!Ce tirage au sort convient dans l'hemisphere nord.
c  Dans l'hemisphere sud,il faut decaler de six mois, c.a.d 
c  prendre les 181 premiers jours et les placer aux 181 dernieres 
c  positions puis prendre les 184 derniers jours et les placer 
c  aux 184 premieres cases du tableau (meme principe pour les 
c  nombres de jours de pluie).!!!!!!
c
c  Si on l'utilise comme routine,on a interet a la lancer en 
c  demandant de sortir les tablaux occurrence (suite des jours 
c  d'une annee pour les 176 categories) , nombrejp(nombre de
c  jours de pluie des 12 mois de l'anne pour les 176 categories)
c  et listezone (liste des 176 categories en question)
c  pour chaque pixel,il faudra commencer par en etablir 
c  la categorie et memoriser en quelle position arrive 
c  cette categorie dans le tableau listezone
c
c  INPUTS: (1) At input, the user must supply the "seed" for 
c            generation and his choice for printing generator outputs:
c             - graine: seed for generation (any real*4 value)
c               Changing graine from one call to the other allows
c               to change the calculated distribution at random,
c               while keeping consistency with the climate statistics.
c             - iprint=1/0 to print (1) or not print (0) outputs from
c               weather generator, i.e., contents of common /gene/
c               (see below) on unit 23 (binary file to be opened by 
c               user). This is useful to avoid call to generator
c               in later applications using the same characteristics.
c            No other input needs to be supplied by the user. 
c          (2) The necessary data (weather statistics for every 
c            climatic zone) are read by "generator" or its subroutines 
c            into data files_ibm stored in /ALLSTAT/... directories.
c          (3) subroutine "ctgen" must be called prior to the call to
c            "generator" to set a series of constants, including the
c            names of the 176 geoclimatic zones (vector listzone)
c          (4) "pathgene" a character*80 variable in common "pathg"
c            must contain the name of the directory in which /ALLSTAT
c            can be found
c 
c  OUTPUTS: The outputs of "generator" are returned in common /gene/.
c           These outputs provides the relative distribution over 1 year
c           of daily precipitation (P), daily temperature (T), and 
c           daily amplitude of diurnal temperature signal Tmax-Tmin (DT)
c           - rapportP(izon,iday): ratio of daily precipitation at day 
c                      "iday" to monthly precipitation in geoclimatic 
c                      zone "izon". The sum of rapportP over a given 
c                      month is equal to 1.
c           - rapportT(izon,iday): ratio of daily temperature in Kelvin
c                      at day "iday" to monthly mean temperature (K) in 
c                      geoclimatic zone "izon". The mean of rapportT 
c                      over a given month is equal to 1.
c           - rapportDT(izon,iday): ratio of daily amplitude of diurnal 
c                      temperature signal (i.e. Tmax-Tmin) at day "iday"
c                      to its monthly mean average in geoclimatic zone
c                      "izon". The mean of rapportDT over a given
c                      month is equal to 1. 
c           - ioccu(izon): occurrence of precipitation at day "iday" in
c                      geoclimatic zone "izon". "ioccu" is equal to 1 if
c                      precipitation occurs at days and 0 otherwise.
c           - nombrejp(izon,im): number of rainy days in month "im" and 
c                      geoclimatic zone "izon" for northern hemisphere.
c           - nombrejpS(izon,im): number of rainy days in month "im" and
c                      geoclimatic zone "izon" for southern hemisphere.
c           The outputs may be printed on unit 23 at the end of the 
c           subroutine to be read and used by another application. This 
c           avoids the call to "generator" and reduces compting time.
c=======================================================================
      implicit none
      
      include './com_18/parameter.common'
      include './com_18/gene.common'
      include './com_18/lstz.common'
      include './com_18/monthcst.common'
      include './com_18/pathg.common'
c-----------------------------------------------
c JLP ajout� pour implicit none
c
      integer i,iday,iprint,izone,j,jm,k,kdays,kf,knorm1,knorm2,m,mth,n
     &      ,nbrstat
c
c-----------------------------------------------

      real*4 p(nm),pp(nm),ss(nm),pm(nm),ppm(nm),ssm(nm),proba,hasard
      real*4 graine,ampligraine,rampli,rap
      real*4 alpha1
      real*4 tabrT(ndy),tabrDT(ndy)

      integer l
      integer flag(ndy)

      character*110 filename

      do i=1,nzone
         do j=1,nd
            ioccu(i,j)=1
            rapportP(i,j)=0.0
            rapportT(i,j)=0.0
            rapportDT(i,j)=0.0
         enddo
      enddo

      call charlen(pathgene,kf)

      ampligraine=graine+0.23
      do i=1,nzone
         filename=pathgene(1:kf)//'ALLSTAT/MOYENNES/moy'
     1      //listezone(i)
         open(11,file=filename,status='old')
         read(11,20)nbrstat
20       format(19x,i5)

c=======================================================================
c   p(j) : probability of rain during a given day of month j
c   pp(j): probability of rain during a given day of month j
c          when the previous day has been rainy
c   ss(j): probability of drought during a given day of month j
c          when the previous day has been dry
c   In average, there should exists the following relationship
c   between these three probabilities:
c       (1-p(j))*(1-ss(j)) + p(j)*pp(j) = p(j)
c   i.e.     p(j) = (1-ss(j))/(2-pp(j)-ss(j))
c=======================================================================

         do jm=1,nm
            read(11,30)pm(jm),ppm(jm),ssm(jm)
30          format(8x,f8.6,2(9x,f8.6))
         enddo
         do j=1,nm 
            mth=mondec(j)
            p(j)=pm(mth)
            pp(j)=ppm(mth)
            ss(j)=ssm(mth)
            nombrejp(i,j)=0
         enddo
         close(11)
         l=0
         if(p(1).gt.0.5)then
            l=1
         endif
         k=0
         knorm1=0
         knorm2=0
         do j=1,nm
            mth=mondec(j)
            do n=1,mlength(j)
               k=k+1
               graine=graine+1.14
               call randnum(graine,hasard)
               if(l.eq.1)then
                  proba=pp(j)
               else
                  proba=1.-ss(j)
               endif
               if(hasard.le.proba)then
                  ioccu(i,k)=1
                  l=1
                  call randnum(ampligraine,rampli)
                  call calrapportprecip(listezone(i),mth,rampli,
     &                                  rap)
                  rapportP(i,k)=rap
                  if (rapportP(i,k).le.0.0)then
                    rapportP(i,k)=0.00001
                  endif
                  ampligraine=ampligraine+1.26
                  nombrejp(i,j)=nombrejp(i,j)+1
               else
                  ioccu(i,k)=0
                  rapportP(i,k)=0.
                  l=0
               endif
            enddo

            if (nombrejp(i,j).eq.0) then
               kdays=numday(j) 
               ioccu(i,kdays)=1
               rapportP(i,kdays)=1.0
               nombrejp(i,j)=1
            endif

c=======================================================================
c   normalisation des rapports de precipitation a l'unite.
c=======================================================================

            alpha1=0.0
            do n=1,mlength(j)
               knorm1=knorm1+1
               alpha1=alpha1+rapportP(i,knorm1)
            enddo
            do n=1,mlength(j)
               knorm2=knorm2+1
               if(alpha1.gt.0.0)then
                  rapportP(i,knorm2)=rapportP(i,knorm2)/alpha1
               endif
            enddo
         enddo

c=======================================================================
c   appel a la routine qui calcule les rapports pour T
c=======================================================================

         do j=1,nd
            flag(j)=ioccu(i,j)
         enddo
         call TDT(mlength,mondec,flag,tabrT,tabrDT,listezone(i)
     &           ,ampligraine)

c=======================================================================
c !!! dans TDT, ampligraine est placee dans seed (= graine) !!!
c=======================================================================

         do j=1,nd
            rapportT(i,j)=tabrT(j)
            rapportDT(i,j)=tabrDT(j)
         enddo
      enddo
     
c=======================================================================
c   calcul du nombre de jours de pluie dans l'hemisphere Sud
c=======================================================================

      do izone=1,nzone
         do m=1,nm
            nombrejpS(izone,m)=0
         enddo
         do iday=1,nd
            m = imonth(iday)
            if(iday.le.181)then
               nombrejpS(izone,m)=nombrejpS(izone,m)
     &                           +ioccu(izone,iday+184)
            else
               nombrejpS(izone,m)=nombrejpS(izone,m)
     &                           +ioccu(izone,iday-181)
            endif
         enddo
      enddo
        
      if (iprint.eq.1) then
         write(23) rapportP
         write(23) rapportT
         write(23) rapportDT
         write(23) ioccu
         write(23) nombrejp
         write(23) nombrejpS
      endif

      return
      end subroutine generator